@@ -16,11 +16,11 @@ router = routers.DefaultRouter()
 router.register(r'tenants', SharePointTenantViewSet, basename='sharepoint-tenant')
 router.register(r'sites', SharePointSiteViewSet, basename='sharepoint-site')
 router.register(r'libraries', SharePointLibraryViewSet, basename='sharepoint-library')
-router.register(r'sharepoint/(?P<tenant>[\w\-]+)/(?P<site>[\w\-]+)/(?P<folder>[\w|\W]+)/files',
+router.register(r'sharepoint/(?P<tenant>[\w\-]+)/(?P<site>[\w\-]+)/(?P<folder>[\w\W]+)/files',
                 FileSharePointViewSet, basename='sharepoint-files')
-router.register(r'sharepoint/(?P<tenant>[\w\-]+)/(?P<site>[\w\-]+)/(?P<folder>[\w|\W]+)',
+router.register(r'sharepoint/(?P<tenant>[\w\-]+)/(?P<site>[\w\-]+)/(?P<folder>[\w\W]+)/rest',
                 ItemSharePointViewSet, basename='sharepoint')
-router.register(r'sharepoint-caml/(?P<tenant>[\w\-]+)/(?P<site>[\w\-]+)/(?P<folder>[\w|\W]+)',
+router.register(r'sharepoint/(?P<tenant>[\w\-]+)/(?P<site>[\w\-]+)/(?P<folder>[\w\W]+)/caml',
                 ItemSharePointCamlViewSet, basename='sharepoint-caml')
 
 urlpatterns = router.urls
